summaryrefslogtreecommitdiff
path: root/main.cpp
diff options
context:
space:
mode:
authorPaul Buetow <paul@buetow.org>2013-04-06 13:14:46 +0200
committerPaul Buetow <paul@buetow.org>2013-04-06 13:14:46 +0200
commit07706f56cd421bf8b101a5c0fe44674d36e161a0 (patch)
treebec8b45765788370fbd148d68e05d8b437e60670 /main.cpp
parent56187184e11b085b82584d3b088c62f427aae83c (diff)
tagging ychat-0.5.1ychat-0.5.1
Diffstat (limited to 'main.cpp')
-rwxr-xr-xmain.cpp48
1 files changed, 30 insertions, 18 deletions
diff --git a/main.cpp b/main.cpp
index 2cbc713..08f89f8 100755
--- a/main.cpp
+++ b/main.cpp
@@ -1,6 +1,6 @@
/*
- * yChat++; Homepage: www.yChat.org
- * Copyright (C) 2003 Paul C. Buetow ( Snooper@yChat.org, ICQ: 11655527 )
+ * yChat++; Contact: www.yChat.org; Mail@yChat.org
+ * Copyright (C) 2003 Paul C. Buetow, Volker Richter
* -----------------------------------------------------------------
*
* This program is free software; you can redistribute it and/or
@@ -26,25 +26,34 @@
#include "incl.h"
// include the chat manager.
-#include "CHAT.h"
+#include "s_chat.h"
// include the config manager.
-#include "CONF.h"
+#include "s_conf.h"
// include the html-template manager.
-#include "HTML.h"
+#include "s_html.h"
// include the mutex manager for global synchronization.
-#include "MUTX.h"
+#include "s_mutx.h"
+
+// include the module loader manager for global synchronization.
+#include "s_modl.h"
// include the socket manager.
-#include "SOCK.h"
+#include "s_sock.h"
+
+// include the language manager
+#include "s_lang.h"
+
+// include the session manager
+#include "s_sman.h"
using namespace std;
int main()
{
-#ifdef _VERBOSE
+#ifdef VERBOSE
cout << " ___ _ _ " << endl
<< " _ _ / __\\ |__ __ _| |_ " << endl
@@ -66,19 +75,22 @@ cout << " ___ _ _ " << endl
// all the static data classes have to be initialized once. otherwise they will
// contain only empty pointers and the chat server won't work correctly.
- // the order of the initializations is very importand. for example the HTML::init()
- // invokations assumes an initialized CONF class.
- MUTX::init(); // init the mutex manager.
- CONF::init(); // init the config manager.
- HTML::init(); // init the html-template manager.
- SOCK::init(); // init the socket manager.
- CHAT::init(); // init the chat manager.
-
+ // the order of the initializations is very importand. for example the s_html::init()
+ // invokations assumes an initialized s_conf class.
+ s_mutx::init(); // init the mutex manager.
+ s_conf::init(); // init the config manager.
+ s_html::init(); // init the html-template manager.
+ s_lang::init(); // init the language manager
+ s_sman::init(); // init the session manager.
+ s_modl::init(); // init the module-loader manager.
+ s_sock::init(); // init the socket manager.
+ s_chat::init(); // init the chat manager.
+
// start the socket manager. this one will listen for incoming http requests and will
// forward them to the specified routines which will generate a http response.
- SOCK::get().start();
+ s_sock::get().start();
-#ifdef _VERBOSE
+#ifdef VERBOSE
cout << DOWNMSG << endl;
#endif